@@ -20,8 +20,8 @@
  * CVS Information:
  *
  *  $Source: /home/globdev/CVS/globus-packages/gatekeeper/source/globus_gatekeeper.c,v $
- *  $Date: 2012/02/08 17:53:47 $
- *  $Revision: 1.110.2.3 $
+ *  $Date: 2012/07/17 18:56:53 $
+ *  $Revision: 1.110.2.5 $
  *  $Author: bester $
  *
  * This source file has been modified by Brent Milne (BMilne@lbl.gov)
@@ -504,16 +504,6 @@ main(int xargc,
         exit(1);
     }
 
-    /* 
-     * Don't allow logins of /etc/nologin exists. 
-     * Silently ignore them, as the sysadmin
-     * must have other problems.
-     */
-    if (access("/etc/nologin", F_OK) == 0)
-    {
-        exit (1);
-    }
-
     gatekeeper_pid = getpid();
 
     gatekeeper_uid = getuid();
@@ -958,7 +948,12 @@ main(int xargc,
         act.sa_handler = SIG_IGN;
         sigemptyset(&act.sa_mask);
         sigaddset(&act.sa_mask, SIGCHLD);
+#ifdef SA_NOCLDWAIT
         act.sa_flags = SA_NOCLDWAIT;
+#else
+        /* This might leave zombies on non-POSIX systems like Hurd */
+        act.sa_flags = 0;
+#endif
         sigaction(SIGCHLD, &act, NULL);
         if (!run_from_inetd)
         {
@@ -1328,23 +1323,27 @@ static void doit()
 
     notice3(LOG_INFO, "Got connection %s at %s", peernum, timestamp());
 
-    /* Do gss authentication here */
-
     /* 
      * if globus nologin is set, error message and exit
      */
         
+    if (access("/etc/nologin", F_OK) == 0)
+    {
+        failure(FAILED_NOLOGIN, 
+                "Not accepting connections at this time (/etc/nologin)");
+    }
+
     if (getenv("GLOBUS_LOCATION") != NULL &&
         access(genfilename(gatekeeperhome,"etc",globusnologin), F_OK) == 0)
     {
         failure(FAILED_NOLOGIN, 
-                "Not accepting connections at this time");
+                "Not accepting connections at this time ($GLOBUS_LOCATION/etc/nologin)");
     }
 
     if (access("/etc/globus-nologin", F_OK) == 0)
     {
         failure(FAILED_NOLOGIN, 
-                "Not accepting connections at this time");
+                "Not accepting connections at this time (/etc/globus-nologin)");
     }
 
     /* 
